/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.mock;

import java.text.FieldPosition;
import java.text.ParsePosition;
import java.util.HashMap;
import java.util.Map;
import java.text.Format;
import it.tidalwave.metadata.spi.MetadataItemFormatProvider;

class SuffixFormat extends Format
  {
    private final String suffix;

    public SuffixFormat (final String suffix) 
      {
        this.suffix = suffix;
      }
    
    @Override
    public StringBuffer format (final Object object, final StringBuffer toAppendTo, final FieldPosition pos) 
      {
        toAppendTo.append(object.toString().trim()).append(" ").append(suffix);
        return toAppendTo;
      }

    @Override
    public Object parseObject (final String source, final ParsePosition pos) 
      {
        pos.setIndex(pos.getIndex() + source.length());
        return source.replaceAll(suffix + "$", "").trim();
      }
    
  }

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemMock2Format implements MetadataItemFormatProvider<MockItem2>
  {
    private final Map<String, Format> formatMapByPropertyName = new HashMap<String, Format>();
    private final Map<String, String> displayNameMapByPropertyName = new HashMap<String, String>();
    
    public MetadataItemMock2Format()
      {
        formatMapByPropertyName.put("name", new SuffixFormat("EV"));
        formatMapByPropertyName.put("value", new SuffixFormat("mm"));
        displayNameMapByPropertyName.put("name", "NAME");
        displayNameMapByPropertyName.put("value", "VALUE");
      }    

    public Class<MockItem2> getItemClass()
      {
        return MockItem2.class;
      }
    
    public String getItemDisplayName() 
      {
        return "Mock Item 2";
      }

    public Format getFormat (final String propertyName) 
      {
        return formatMapByPropertyName.get(propertyName);
      }

    public String getDisplayName (String propertyName) 
      {
        return displayNameMapByPropertyName.get(propertyName);
      }
  }
