/***********************************************************************************************************************
 *
 * blueMarine Metadata - open source media workflow
 * Copyright (C) 2007-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~metadata-src
 *
 **********************************************************************************************************************/
package it.tidalwave.metadata.spi;

import java.util.Date;
import java.util.List;
import java.util.Iterator;
import java.io.IOException;
import org.openide.loaders.DataObject;
import it.tidalwave.metadata.Metadata.StorageType;
import it.tidalwave.metadata.MetadataItemHolder;
import it.tidalwave.metadata.mock.MetadataItemProviderMock1;
import it.tidalwave.metadata.mock.MockItem1;
import it.tidalwave.metadata.mock.MetadataItemSourceMock1b;
import it.tidalwave.metadata.mock.MetadataItemSourceMock1a;
import it.tidalwave.metadata.mock.MetadataItemSourceMock1Internal;
import org.junit.Test;
import static org.junit.Assert.*;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class MetadataItemProviderSupportTest extends TestSupport
  {
    @Test
    public void testFindMetatadaItemsWithNullDataObject()
      {
        try
          {
            final MetadataItemProviderSupport mips = new MetadataItemProviderMock1();
//            final MetadataItemProviderSupport mips = new MetadataItemProviderSupport<MockItem1>(MockItem1.class, ENHANCED) {};
            mips.findOrCreateItems(null);
            fail("IllegalArgumentException expected");
          }
        catch (IllegalArgumentException e)
          {
            // ok
          }
      }
    
    @Test
    public void testFindMetatadaItemsWithNullOption() 
      throws IOException
      {
        try
          {
            final MetadataItemProviderSupport mips = new MetadataItemProviderMock1();
                    //new MetadataItemProviderSupport<MockItem1>(MockItem1.class, ENHANCED) {};
            final DataObject dataObject = createDataObject("xxx");
            mips.findOrCreateItems(dataObject, null);
            fail("IllegalArgumentException expected");
          }
        catch (IllegalArgumentException e)
          {
            // ok
          }
      }
    
    @Test
    public void testFindMetadataItemSources() 
      {
        final List<MetadataItemSource<MockItem1>> sources = MetadataItemProviderSupport.findMetadataItemSources(MockItem1.class);
        assertNotNull(sources);
        assertEquals(3, sources.size());
        final MetadataItemSource<MockItem1> source1 = sources.get(0);
        final MetadataItemSource<MockItem1> source2 = sources.get(1);
        final MetadataItemSource<MockItem1> source3 = sources.get(2);
        assertNotNull(source1);
        assertNotNull(source2);
        assertNotNull(source3);
        assertTrue(source1 != source2);
        assertTrue(source1 != source3);
        assertTrue(source2 != source3);
        assertTrue(source1 instanceof MetadataItemSourceMock1a);
        assertTrue(source2 instanceof MetadataItemSourceMock1b);
        assertTrue(source3 instanceof MetadataItemSourceMock1Internal);
      }

    @Test
    public void testFindMetadataItems()
      throws IOException 
      {
        final DataObject dataObject = createDataObject("xxx");
        final List<MetadataItemHolder<MockItem1>> holders = MetadataItemProviderSupport.findItems(MockItem1.class, dataObject, StorageType.ANY_TYPE);
        final Iterator<MetadataItemHolder<MockItem1>> i = holders.iterator();
        final MetadataItemHolder<MockItem1> holder1 = i.next();
        final MetadataItemHolder<MockItem1> holder2 = i.next();
        assertNotNull(holder1);
        assertNotNull(holder2);
        
        final MockItem1 item1 = holder1.get();
        final MockItem1 item2 = holder2.get();
        assertNotNull(item1);
        assertNotNull(item2);
        assertTrue(item1 != item2);
        assertTrue(item1 instanceof MockItem1);
        assertTrue(item2 instanceof MockItem1);
        final Date timestamp1 = holder1.getLatestModificationTime();
        assertNotNull(timestamp1);
        final Date timestamp2 = holder2.getLatestModificationTime();
        assertNotNull(timestamp2);
        assertTrue(timestamp1.after(timestamp2));
      }
  }
